SmoothOperation class

Constructors

SmoothOperation({SmoothMatrix4OperationType? operation, double? rotationX, double? rotationY, double? rotationZ, double? scaleX, double? scaleY, Dimension? translateX, Dimension? translateY})
SmoothOperation.fromJson(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
operation ↔ SmoothMatrix4OperationType?
getter/setter pair
rotationX ↔ double?
getter/setter pair
rotationY ↔ double?
getter/setter pair
rotationZ ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleX ↔ double?
getter/setter pair
scaleY ↔ double?
getter/setter pair
translateX ↔ Dimension?
getter/setter pair
translateY ↔ Dimension?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited