GlobalAnimation class

Constructors

GlobalAnimation({required Map<String, MultiAnimationSequence> sequences, double beginShift = 0.0, double endShift = 0.0, CustomAnimationControl control = CustomAnimationControl.PLAY})
GlobalAnimation.fromJson(Map map)

Properties

beginShift ↔ double
getter/setter pair
control ↔ CustomAnimationControl
getter/setter pair
endShift ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequences ↔ Map<String, MultiAnimationSequence>
getter/setter pair

Methods

getAllTimeStamps() → List<double>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rescaleTime(Duration maxDuration) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

progressMaxTime → const double