FadeOutAnimation class

Inheritance

Constructors

FadeOutAnimation({Duration duration = const Duration(seconds: 1), Duration delay = Duration.zero, Curve curve = Curves.linear, CustomAnimationControl control = CustomAnimationControl.PLAY})
const

Properties

control → CustomAnimationControl
finalinherited
curve → Curve
finalinherited
delay → Duration
finalinherited
duration → Duration
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAnimationSequence() → MultiAnimationSequence
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited