StyledRadio<T> class

Inheritance

Constructors

StyledRadio({Key? key, required T value, required T? groupValue, required ValueChanged<T?>? onChanged, required Style style, Style? hoveredStyle, Style? selectedStyle, Style? disabledStyle, Curve curve = Curves.linear, Duration duration = const Duration(milliseconds: 100), Widget? child, StyledComponentStateChildBuilder? builder})

Properties

builder → StyledComponentStateChildBuilder?
final
child → Widget?
final
curve → Curve
final
disabledStyle → Style?
final
duration → Duration
final
groupValue → T?
final
hashCode → int
The hash code for this object.
no setterinherited
hoveredStyle → Style?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → ValueChanged<T?>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedStyle → Style?
final
style → Style
final
value → T
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited